/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__iegsN9bf6GqRiWprrJjTAoA[1];
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_27)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__extccomp_1071)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* c);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__extccomp_756)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOption__extccomp_692)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOption__extccomp_695)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addLocalCompileOption__extccomp_740)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option, NimStringDesc* nimfile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__msgs_581)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_2530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, NimStringDesc* define);
N_LIB_PRIVATE N_NIMCALL(NI64, getOrDefault__vm_4290)(tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_4732)(tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g* t, NimStringDesc* key, NI64 val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_8141)(tyObject_Table__R7JnJQEipxxOlJWXQz7jWg t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_8462)(tyObject_Table__R7JnJQEipxxOlJWXQz7jWg* t, NimStringDesc* key, tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q val);
N_LIB_PRIVATE N_NIMCALL(void, initBTree__vm_8401)(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_9768)(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q b, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q*, X5BX5D___vm_9635)(tyObject_Table__R7JnJQEipxxOlJWXQz7jWg* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, add__vm_10052)(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q* b, NimStringDesc* key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_5915)(tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_6210)(tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q* t, NimStringDesc* key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTree__ast_3356)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**, X5BX5D___vm_7379)(tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_56)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, translateId__icZic_8428)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI thisModule, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(tySequence__dlD6tEGzYLLpKVq3XwuFlA**, mgetOrPut__semdata_2458)(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tySequence__dlD6tEGzYLLpKVq3XwuFlA* val);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tySequence__UnGSk9aaLosDroi2QDrlOfQ*, newSeq__icZreplayer_1072)(NI len);
N_LIB_PRIVATE N_NIMCALL(tySequence__6OFCSvqRaxyEgUqWtnZSlw**, mgetOrPut__semdata_1249)(tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tySequence__6OFCSvqRaxyEgUqWtnZSlw* val);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tySequence__m4PVWjcAAjfxlwJxLkKn8A**, mgetOrPut__modulegraphs_7763)(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tySequence__m4PVWjcAAjfxlwJxLkKn8A* val);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_6117)(tyObject_Table__1hIWbTQWYT4BmhdESze57A* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, loadSymFromId__icZic_8413)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI module, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id);
N_LIB_PRIVATE N_NIMCALL(void, methodDef__cgmeth_264)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_2, "(", 1);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_3, ", ", 2);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_4, ")", 1);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_6, "/home/runner/work/nightlies/nightlies/nim/compiler/ic/replayer.nim", 66);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__N5M6b9cz9aCakDdwShXiixyw_5 = {((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_6),
((NI) 30),
((NI) 21)}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_7, "hint", 4);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_8, "warning", 7);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_9, "error", 5);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_10, "compile", 7);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_11, "link", 4);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_12, "passl", 5);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_13, "passc", 5);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_14, "localpassc", 10);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_15, "cppdefine", 9);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_16, "inc", 3);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_17, "put", 3);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_18, "incl", 4);
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_19, "add", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__N5M6b9cz9aCakDdwShXiixyw_20 = {((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_6),
((NI) 32),
((NI) 24)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__N5M6b9cz9aCakDdwShXiixyw_21 = {((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_6),
((NI) 33),
((NI) 27)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__N5M6b9cz9aCakDdwShXiixyw_22 = {((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_6),
((NI) 34),
((NI) 28)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__N5M6b9cz9aCakDdwShXiixyw_23 = {((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_6),
((NI) 36),
((NI) 23)}
;
STRING_LITERAL(TM__N5M6b9cz9aCakDdwShXiixyw_24, "key already exists: ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__N5M6b9cz9aCakDdwShXiixyw_25 = {((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_6),
((NI) 67),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__N5M6b9cz9aCakDdwShXiixyw_26 = {((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_6),
((NI) 87),
((NI) 23)}
;
extern TNimType NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_;
extern TNimType NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_;
extern TNimType NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_;
extern TNimType NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_;
extern TNimType NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_2));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_3));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_4));
	}
	LA3_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, replayStateChanges__icZreplayer_15)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* list;
	list = (*module).ast;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		n = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(list);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					n = (*list)._kind_6.sons->data[i];
					{
						NI T7_;
						T7_ = (NI)0;
						T7_ = len__ast_3155(n);
						if (!(((NI) 2) <= T7_)) goto LA8_;
						{
							NIM_BOOL T12_;
							NimStringDesc* argX60gensym10_;
							T12_ = (NIM_BOOL)0;
							T12_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20));
							if (!(T12_)) goto LA13_;
							T12_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20));
							LA13_: ;
							if (!!(T12_)) goto LA14_;
							argX60gensym10_ = toFileLineCol__msgs_625(TM__N5M6b9cz9aCakDdwShXiixyw_5);
							internalErrorImpl__msgs_1441((*g).config, unknownLineInfo__lineinfos_284, argX60gensym10_, TM__N5M6b9cz9aCakDdwShXiixyw_5);
						}
						LA14_: ;
						switch (hashString((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal) & 15) {
						case 0: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_10))) goto LA19_;
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_11))) goto LA20_;
break;
						case 2: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_19))) goto LA28_;
break;
						case 3: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_16))) goto LA25_;
break;
						case 4: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_15))) goto LA24_;
break;
						case 5: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_12))) goto LA21_;
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_17))) goto LA26_;
break;
						case 11: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_7))) goto LA16_;
break;
						case 12: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_8))) goto LA17_;
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_9))) goto LA18_;
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_13))) goto LA22_;
break;
						case 13: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_14))) goto LA23_;
break;
						case 15: 
if (eqStrings((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_18))) goto LA27_;
break;
						}
						goto LA29_;
						LA16_: ;
						{
							liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 102), (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__N5M6b9cz9aCakDdwShXiixyw_20, NIM_FALSE);
						}
						goto LA30_;
						LA17_: ;
						{
							liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71), (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__N5M6b9cz9aCakDdwShXiixyw_21, NIM_FALSE);
						}
						goto LA30_;
						LA18_: ;
						{
							liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 16), (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__N5M6b9cz9aCakDdwShXiixyw_22, NIM_FALSE);
						}
						goto LA30_;
						LA19_: ;
						{
							NimStringDesc* cname;
							tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw cf;
							tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T42_;
							{
								NIM_BOOL T37_;
								NI T38_;
								NimStringDesc* argX60gensym23_;
								T37_ = (NIM_BOOL)0;
								T38_ = (NI)0;
								T38_ = len__ast_3155(n);
								T37_ = (T38_ == ((NI) 4));
								if (!(T37_)) goto LA39_;
								T37_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20));
								LA39_: ;
								if (!!(T37_)) goto LA40_;
								argX60gensym23_ = toFileLineCol__msgs_625(TM__N5M6b9cz9aCakDdwShXiixyw_23);
								internalErrorImpl__msgs_1441((*g).config, unknownLineInfo__lineinfos_284, argX60gensym23_, TM__N5M6b9cz9aCakDdwShXiixyw_23);
							}
							LA40_: ;
							cname = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal;
							nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw));
							nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw));
							nimZeroMem((void*)(&T42_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
							splitFile__pathutils_27(cname, (&T42_));
							cf.nimname = copyString(T42_.Field1);
							cf.cname = copyString(cname);
							cf.obj = copyString((*(*n)._kind_6.sons->data[((NI) 2)])._kind_3.strVal);
							cf.flags = 2;
							cf.customArgs = copyString((*(*n)._kind_6.sons->data[((NI) 3)])._kind_3.strVal);
							addExternalFileToCompile__extccomp_1071((*g).config, (&cf));
						}
						goto LA30_;
						LA20_: ;
						{
							addExternalFileToLink__extccomp_756((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
						}
						goto LA30_;
						LA21_: ;
						{
							addLinkOption__extccomp_692((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
						}
						goto LA30_;
						LA22_: ;
						{
							addCompileOption__extccomp_695((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
						}
						goto LA30_;
						LA23_: ;
						{
							NimStringDesc* T47_;
							T47_ = NIM_NIL;
							T47_ = toFullPathConsiderDirty__msgs_581((*g).config, (*module).info.fileIndex);
							addLocalCompileOption__extccomp_740((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal, T47_);
						}
						goto LA30_;
						LA24_: ;
						{
							cppDefine__options_2530((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
						}
						goto LA30_;
						LA25_: ;
						{
							NimStringDesc* destKey;
							NI64 by;
							NI64 v;
							destKey = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal;
							by = (*(*n)._kind_6.sons->data[((NI) 2)])._kind_1.intVal;
							v = getOrDefault__vm_4290((*g).cacheCounters, destKey);
							X5BX5Deq___vm_4732((&(*g).cacheCounters), destKey, (NI64)(v + by));
						}
						goto LA30_;
						LA26_: ;
						{
							NimStringDesc* destKey_2;
							NimStringDesc* key;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val;
							destKey_2 = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal;
							key = (*(*n)._kind_6.sons->data[((NI) 2)])._kind_3.strVal;
							val = (*n)._kind_6.sons->data[((NI) 3)];
							{
								NIM_BOOL T53_;
								tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q T56_;
								T53_ = (NIM_BOOL)0;
								T53_ = contains__vm_8141((*g).cacheTables, destKey_2);
								if (!!(T53_)) goto LA54_;
								nimZeroMem((void*)(&T56_), sizeof(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q));
								initBTree__vm_8401((&T56_));
								X5BX5Deq___vm_8462((&(*g).cacheTables), destKey_2, T56_);
							}
							LA54_: ;
							{
								tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q* T59_;
								NIM_BOOL T60_;
								tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q* T63_;
								T59_ = (tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q*)0;
								T59_ = X5BX5D___vm_9635((&(*g).cacheTables), destKey_2);
								T60_ = (NIM_BOOL)0;
								T60_ = contains__vm_9768((*T59_), key);
								if (!!(T60_)) goto LA61_;
								T63_ = (tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q*)0;
								T63_ = X5BX5D___vm_9635((&(*g).cacheTables), destKey_2);
								add__vm_10052(T63_, key, val);
							}
							goto LA57_;
							LA61_: ;
							{
								NimStringDesc* T65_;
								T65_ = NIM_NIL;
								T65_ = rawNewString((key ? key->Sup.len : 0) + 20);
appendString(T65_, ((NimStringDesc*) &TM__N5M6b9cz9aCakDdwShXiixyw_24));
appendString(T65_, key);
								internalErrorImpl__msgs_1441((*g).config, (*n).info, T65_, TM__N5M6b9cz9aCakDdwShXiixyw_25);
							}
							LA57_: ;
						}
						goto LA30_;
						LA27_: ;
						{
							NimStringDesc* destKey_3;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val_2;
							destKey_3 = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal;
							val_2 = (*n)._kind_6.sons->data[((NI) 2)];
							{
								NIM_BOOL T69_;
								tyArray__iegsN9bf6GqRiWprrJjTAoA T72_;
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T73_;
								T69_ = (NIM_BOOL)0;
								T69_ = contains__vm_5915((*g).cacheSeqs, destKey_3);
								if (!!(T69_)) goto LA70_;
								nimZeroMem((void*)T72_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
								T72_[0] = val_2;
								T73_ = NIM_NIL;
								T73_ = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), T72_, 1);
								X5BX5Deq___vm_6210((&(*g).cacheSeqs), destKey_3, T73_);
							}
							goto LA67_;
							LA70_: ;
							{
								{
									tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T86_;
									{
										tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* existing;
										tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp__2;
										tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T77_;
										existing = NIM_NIL;
										colontmp__2 = NIM_NIL;
										T77_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
										T77_ = X5BX5D___vm_7379((&(*g).cacheSeqs), destKey_3);
										colontmp__2 = (*T77_);
										{
											NI i_3;
											NI colontmp__3;
											NI i_4;
											i_3 = (NI)0;
											colontmp__3 = (NI)0;
											colontmp__3 = safeLen__ast_3148(colontmp__2);
											i_4 = ((NI) 0);
											{
												while (1) {
													if (!(i_4 < colontmp__3)) goto LA80;
													i_3 = i_4;
													existing = (*colontmp__2)._kind_6.sons->data[i_3];
													{
														NIM_BOOL T83_;
														T83_ = (NIM_BOOL)0;
														T83_ = exprStructuralEquivalent__trees_56(existing, val_2, NIM_TRUE);
														if (!T83_) goto LA84_;
														goto LA75;
													}
													LA84_: ;
													i_4 += ((NI) 1);
												} LA80: ;
											}
										}
									}
									T86_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
									T86_ = X5BX5D___vm_7379((&(*g).cacheSeqs), destKey_3);
									add__ast_4798((*T86_), val_2);
								} LA75: ;
							}
							LA67_: ;
						}
						goto LA30_;
						LA28_: ;
						{
							NimStringDesc* destKey_4;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val_3;
							destKey_4 = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal;
							val_3 = (*n)._kind_6.sons->data[((NI) 2)];
							{
								NIM_BOOL T90_;
								tyArray__iegsN9bf6GqRiWprrJjTAoA T93_;
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T94_;
								T90_ = (NIM_BOOL)0;
								T90_ = contains__vm_5915((*g).cacheSeqs, destKey_4);
								if (!!(T90_)) goto LA91_;
								nimZeroMem((void*)T93_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
								T93_[0] = val_3;
								T94_ = NIM_NIL;
								T94_ = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), T93_, 1);
								X5BX5Deq___vm_6210((&(*g).cacheSeqs), destKey_4, T94_);
							}
							goto LA88_;
							LA91_: ;
							{
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T96_;
								T96_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
								T96_ = X5BX5D___vm_7379((&(*g).cacheSeqs), destKey_4);
								add__ast_4798((*T96_), val_3);
							}
							LA88_: ;
						}
						goto LA30_;
						LA29_: ;
						{
							{
								NimStringDesc* argX60gensym44_;
								if (!NIM_TRUE) goto LA100_;
								argX60gensym44_ = toFileLineCol__msgs_625(TM__N5M6b9cz9aCakDdwShXiixyw_26);
								internalErrorImpl__msgs_1441((*g).config, unknownLineInfo__lineinfos_284, argX60gensym44_, TM__N5M6b9cz9aCakDdwShXiixyw_26);
							}
							LA100_: ;
						}
						LA30_: ;
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, replayGenericCacheInformation__icZreplayer_977)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module) {
	{
		tyTuple__Db8CrQifKGIsKc3w71w7Lw* it;
		tySequence__oKtVqsc9bQVCNyrijELM4OQ* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyTuple__Db8CrQifKGIsKc3w71w7Lw*)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*g).packed_0->data[module].fromDisk.typeInstCache;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key;
				tySequence__dlD6tEGzYLLpKVq3XwuFlA* T5_;
				tySequence__dlD6tEGzYLLpKVq3XwuFlA** T6_;
				tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ T7_;
				NI T8_;
				if (!(i < L)) goto LA4;
				it = (&colontmp_->data[i]);
				key = translateId__icZic_8428((*it).Field0, (*g).packed_0, module, (*g).config);
				T5_ = NIM_NIL;
				T5_ = NIM_NIL;
				T6_ = (tySequence__dlD6tEGzYLLpKVq3XwuFlA**)0;
				T6_ = mgetOrPut__semdata_2458((&(*g).typeInstCache), key, T5_);
				nimZeroMem((void*)(&T7_), sizeof(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ));
				nimZeroMem((void*)(&T7_), sizeof(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ));
				nimZeroMem((void*)(&T7_.id), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
				T7_.id.module = module;
				T7_.id.packed_0 = (*it).Field1;
				T7_.typ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
				unsureAsgnRef((void**) (&(*T6_)), (tySequence__dlD6tEGzYLLpKVq3XwuFlA*) incrSeqV3((TGenericSeq*)((*T6_)), (&NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_)));
				T8_ = (*T6_)->Sup.len++;
				(*T6_)->data[T8_].id = T7_.id;
				asgnRef((void**) (&(*T6_)->data[T8_].typ), T7_.typ);
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg* it_2;
		NI i_2;
		NI L_2;
		NI T10_;
		it_2 = (tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg*)0;
		i_2 = ((NI) 0);
		T10_ = ((*g).packed_0->data[module].fromDisk.procInstCache ? (*g).packed_0->data[module].fromDisk.procInstCache->Sup.len : 0);
		L_2 = T10_;
		{
			while (1) {
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key_2;
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg sym;
				tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
				NI T13_;
				tySequence__6OFCSvqRaxyEgUqWtnZSlw* T19_;
				tySequence__6OFCSvqRaxyEgUqWtnZSlw** T20_;
				tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q T21_;
				NI T22_;
				if (!(i_2 < L_2)) goto LA12;
				it_2 = (&(*g).packed_0->data[module].fromDisk.procInstCache->data[i_2]);
				key_2 = translateId__icZic_8428((*it_2).key, (*g).packed_0, module, (*g).config);
				sym = translateId__icZic_8428((*it_2).sym, (*g).packed_0, module, (*g).config);
				T13_ = ((*it_2).concreteTypes ? (*it_2).concreteTypes->Sup.len : 0);
				concreteTypes = newSeq__icZreplayer_1072(((NI) (T13_)));
				{
					NI i_3;
					NI colontmp__2;
					NI T15_;
					NI res;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					T15_ = (((*it_2).concreteTypes ? (*it_2).concreteTypes->Sup.len : 0)-1);
					colontmp__2 = T15_;
					res = ((NI) 0);
					{
						while (1) {
							tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tmp;
							tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg T18_;
							if (!(res <= colontmp__2)) goto LA17;
							i_3 = res;
							tmp = translateId__icZic_8428((*it_2).concreteTypes->data[i_3], (*g).packed_0, module, (*g).config);
							nimZeroMem((void*)(&T18_), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
							T18_.module = ((NI) (tmp.module));
							T18_.packed_0 = (*it_2).concreteTypes->data[i_3];
							concreteTypes->data[i_3] = T18_;
							res += ((NI) 1);
						} LA17: ;
					}
				}
				T19_ = NIM_NIL;
				T19_ = NIM_NIL;
				T20_ = (tySequence__6OFCSvqRaxyEgUqWtnZSlw**)0;
				T20_ = mgetOrPut__semdata_1249((&(*g).procInstCache), key_2, T19_);
				nimZeroMem((void*)(&T21_), sizeof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q));
				nimZeroMem((void*)(&T21_), sizeof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q));
				T21_.module = module;
				nimZeroMem((void*)(&T21_.sym), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
				T21_.sym.module = ((NI) (sym.module));
				T21_.sym.packed_0 = (*it_2).sym;
				genericSeqAssign((&T21_.concreteTypes), concreteTypes, (&NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_));
				T21_.inst = ((tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA*) NIM_NIL);
				unsureAsgnRef((void**) (&(*T20_)), (tySequence__6OFCSvqRaxyEgUqWtnZSlw*) incrSeqV3((TGenericSeq*)((*T20_)), (&NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_)));
				T22_ = (*T20_)->Sup.len++;
				(*T20_)->data[T22_].module = T21_.module;
				(*T20_)->data[T22_].sym = T21_.sym;
				genericSeqAssign((&(*T20_)->data[T22_].concreteTypes), T21_.concreteTypes, (&NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_));
				asgnRef((void**) (&(*T20_)->data[T22_].inst), T21_.inst);
				i_2 += ((NI) 1);
			} LA12: ;
		}
	}
	{
		tyTuple__FEYH9alRJhHD0uTKF2vnIqw* it_3;
		NI i_4;
		NI L_3;
		NI T24_;
		it_3 = (tyTuple__FEYH9alRJhHD0uTKF2vnIqw*)0;
		i_4 = ((NI) 0);
		T24_ = ((*g).packed_0->data[module].fromDisk.methodsPerType ? (*g).packed_0->data[module].fromDisk.methodsPerType->Sup.len : 0);
		L_3 = T24_;
		{
			while (1) {
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key_3;
				NI col;
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tmp_2;
				tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg symId;
				tySequence__m4PVWjcAAjfxlwJxLkKn8A* T27_;
				tySequence__m4PVWjcAAjfxlwJxLkKn8A** T28_;
				tyTuple__RWXAsQlFoGYyEQZp1G65sg T29_;
				tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T30_;
				NI T31_;
				if (!(i_4 < L_3)) goto LA26;
				it_3 = (&(*g).packed_0->data[module].fromDisk.methodsPerType->data[i_4]);
				key_3 = translateId__icZic_8428((*it_3).Field0, (*g).packed_0, module, (*g).config);
				col = (*it_3).Field1;
				tmp_2 = translateId__icZic_8428((*it_3).Field2, (*g).packed_0, module, (*g).config);
				nimZeroMem((void*)(&symId), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
				symId.module = ((NI) (tmp_2.module));
				symId.packed_0 = (*it_3).Field2;
				T27_ = NIM_NIL;
				T27_ = NIM_NIL;
				T28_ = (tySequence__m4PVWjcAAjfxlwJxLkKn8A**)0;
				T28_ = mgetOrPut__modulegraphs_7763((&(*g).methodsPerType), key_3, T27_);
				nimZeroMem((void*)(&T29_), sizeof(tyTuple__RWXAsQlFoGYyEQZp1G65sg));
				T29_.Field0 = col;
				nimZeroMem((void*)(&T30_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				nimZeroMem((void*)(&T30_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				T30_.id = symId;
				T30_.sym = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				T29_.Field1.id = T30_.id;
				T29_.Field1.sym = T30_.sym;
				unsureAsgnRef((void**) (&(*T28_)), (tySequence__m4PVWjcAAjfxlwJxLkKn8A*) incrSeqV3((TGenericSeq*)((*T28_)), (&NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_)));
				T31_ = (*T28_)->Sup.len++;
				(*T28_)->data[T31_].Field0 = T29_.Field0;
				(*T28_)->data[T31_].Field1.id = T29_.Field1.id;
				asgnRef((void**) (&(*T28_)->data[T31_].Field1.sym), T29_.Field1.sym);
				i_4 += ((NI) 1);
			} LA26: ;
		}
	}
	{
		tyTuple__Db8CrQifKGIsKc3w71w7Lw* it_4;
		NI i_5;
		NI L_4;
		NI T33_;
		it_4 = (tyTuple__Db8CrQifKGIsKc3w71w7Lw*)0;
		i_5 = ((NI) 0);
		T33_ = ((*g).packed_0->data[module].fromDisk.enumToStringProcs ? (*g).packed_0->data[module].fromDisk.enumToStringProcs->Sup.len : 0);
		L_4 = T33_;
		{
			while (1) {
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key_4;
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tmp_3;
				tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg symId_2;
				tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T36_;
				if (!(i_5 < L_4)) goto LA35;
				it_4 = (&(*g).packed_0->data[module].fromDisk.enumToStringProcs->data[i_5]);
				key_4 = translateId__icZic_8428((*it_4).Field0, (*g).packed_0, module, (*g).config);
				tmp_3 = translateId__icZic_8428((*it_4).Field1, (*g).packed_0, module, (*g).config);
				nimZeroMem((void*)(&symId_2), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
				symId_2.module = ((NI) (tmp_3.module));
				symId_2.packed_0 = (*it_4).Field1;
				nimZeroMem((void*)(&T36_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				nimZeroMem((void*)(&T36_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				T36_.id = symId_2;
				T36_.sym = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				X5BX5Deq___modulegraphs_6117((&(*g).enumToStringProcs), key_4, T36_);
				i_5 += ((NI) 1);
			} LA35: ;
		}
	}
	{
		NI32* it_5;
		NI i_6;
		NI L_5;
		NI T38_;
		it_5 = (NI32*)0;
		i_6 = ((NI) 0);
		T38_ = ((*g).packed_0->data[module].fromDisk.methods ? (*g).packed_0->data[module].fromDisk.methods->Sup.len : 0);
		L_5 = T38_;
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym_2;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T41_;
				if (!(i_6 < L_5)) goto LA40;
				it_5 = (&(*g).packed_0->data[module].fromDisk.methods->data[i_6]);
				nimZeroMem((void*)(&T41_), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
				T41_.module = ((NU32) 0);
				T41_.item = (*it_5);
				sym_2 = loadSymFromId__icZic_8413((*g).config, (*g).cache, (&(*g).packed_0), module, T41_);
				methodDef__cgmeth_264(g, (*g).idgen, sym_2);
				i_6 += ((NI) 1);
			} LA40: ;
		}
	}
	{
		NI32* it_6;
		NI i_7;
		NI L_6;
		NI T43_;
		it_6 = (NI32*)0;
		i_7 = ((NI) 0);
		T43_ = ((*g).packed_0->data[module].fromDisk.converters ? (*g).packed_0->data[module].fromDisk.converters->Sup.len : 0);
		L_6 = T43_;
		{
			while (1) {
				tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg symId_3;
				tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T46_;
				NI T47_;
				if (!(i_7 < L_6)) goto LA45;
				it_6 = (&(*g).packed_0->data[module].fromDisk.converters->data[i_7]);
				nimZeroMem((void*)(&symId_3), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
				symId_3.module = module;
				nimZeroMem((void*)(&symId_3.packed_0), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
				symId_3.packed_0.module = ((NU32) 0);
				symId_3.packed_0.item = (*it_6);
				nimZeroMem((void*)(&T46_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				nimZeroMem((void*)(&T46_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				T46_.id = symId_3;
				T46_.sym = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				asgnRef((void**) (&(*g).ifaces->data[module].converters), (tySequence__qeAsXh2i1GAL5Nl0g3OP8g*) incrSeqV3((TGenericSeq*)((*g).ifaces->data[module].converters), (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_)));
				T47_ = (*g).ifaces->data[module].converters->Sup.len++;
				(*g).ifaces->data[module].converters->data[T47_].id = T46_.id;
				asgnRef((void**) (&(*g).ifaces->data[module].converters->data[T47_].sym), T46_.sym);
				i_7 += ((NI) 1);
			} LA45: ;
		}
	}
	{
		NI32* it_7;
		NI i_8;
		NI L_7;
		NI T49_;
		it_7 = (NI32*)0;
		i_8 = ((NI) 0);
		T49_ = ((*g).packed_0->data[module].fromDisk.trmacros ? (*g).packed_0->data[module].fromDisk.trmacros->Sup.len : 0);
		L_7 = T49_;
		{
			while (1) {
				tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg symId_4;
				tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T52_;
				NI T53_;
				if (!(i_8 < L_7)) goto LA51;
				it_7 = (&(*g).packed_0->data[module].fromDisk.trmacros->data[i_8]);
				nimZeroMem((void*)(&symId_4), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
				symId_4.module = module;
				nimZeroMem((void*)(&symId_4.packed_0), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
				symId_4.packed_0.module = ((NU32) 0);
				symId_4.packed_0.item = (*it_7);
				nimZeroMem((void*)(&T52_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				nimZeroMem((void*)(&T52_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				T52_.id = symId_4;
				T52_.sym = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				asgnRef((void**) (&(*g).ifaces->data[module].patterns), (tySequence__qeAsXh2i1GAL5Nl0g3OP8g*) incrSeqV3((TGenericSeq*)((*g).ifaces->data[module].patterns), (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_)));
				T53_ = (*g).ifaces->data[module].patterns->Sup.len++;
				(*g).ifaces->data[module].patterns->data[T53_].id = T52_.id;
				asgnRef((void**) (&(*g).ifaces->data[module].patterns->data[T53_].sym), T52_.sym);
				i_8 += ((NI) 1);
			} LA51: ;
		}
	}
	{
		NI32* it_8;
		NI i_9;
		NI L_8;
		NI T55_;
		it_8 = (NI32*)0;
		i_9 = ((NI) 0);
		T55_ = ((*g).packed_0->data[module].fromDisk.pureEnums ? (*g).packed_0->data[module].fromDisk.pureEnums->Sup.len : 0);
		L_8 = T55_;
		{
			while (1) {
				tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg symId_5;
				tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T58_;
				NI T59_;
				if (!(i_9 < L_8)) goto LA57;
				it_8 = (&(*g).packed_0->data[module].fromDisk.pureEnums->data[i_9]);
				nimZeroMem((void*)(&symId_5), sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg));
				symId_5.module = module;
				nimZeroMem((void*)(&symId_5.packed_0), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
				symId_5.packed_0.module = ((NU32) 0);
				symId_5.packed_0.item = (*it_8);
				nimZeroMem((void*)(&T58_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				nimZeroMem((void*)(&T58_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
				T58_.id = symId_5;
				T58_.sym = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				asgnRef((void**) (&(*g).ifaces->data[module].pureEnums), (tySequence__qeAsXh2i1GAL5Nl0g3OP8g*) incrSeqV3((TGenericSeq*)((*g).ifaces->data[module].pureEnums), (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_)));
				T59_ = (*g).ifaces->data[module].pureEnums->Sup.len++;
				(*g).ifaces->data[module].pureEnums->data[T59_].id = T58_.id;
				asgnRef((void**) (&(*g).ifaces->data[module].pureEnums->data[T59_].sym), T58_.sym);
				i_9 += ((NI) 1);
			} LA57: ;
		}
	}
}
